@@ -25,11 +25,20 @@ describe 'ceilometer::agent::polling' do
         end
       }
 
+      it { should contain_user('ceilometer').with(
+        :ensure  => 'present',
+        :name    => 'ceilometer',
+        :gid     => 'ceilometer',
+        :groups  => platform_params[:ceilometer_groups],
+        :require => 'Anchor[ceilometer::install::end]',
+      ) }
+
       it { should contain_package('nova-common').with(
-       :before => /Package\[ceilometer-common\]/
+       :before => /User\[ceilometer\]/
       )}
 
       it {
+        should contain_ceilometer_config('DEFAULT/tenant_name_discovery').with_value('<SERVICE DEFAULT>')
         should contain_ceilometer_config('compute/instance_discovery_method').with_value('<SERVICE DEFAULT>')
         should contain_ceilometer_config('compute/resource_update_interval').with_value('<SERVICE DEFAULT>')
         should contain_ceilometer_config('compute/resource_cache_expiry').with_value('<SERVICE DEFAULT>')
@@ -82,15 +91,69 @@ describe 'ceilometer::agent::polling' do
       }
     end
 
+    context 'with central parameters set' do
+      before do
+        params.merge!(
+          :tenant_name_discovery => false
+        )
+      end
+
+      it {
+        should contain_ceilometer_config('DEFAULT/tenant_name_discovery').with_value(false)
+      }
+    end
+
+    context 'with compute namespace disabled' do
+      before do
+        params.merge!(
+          :compute_namespace => false
+        )
+      end
+
+      it {
+        should contain_ceilometer_config('DEFAULT/polling_namespaces').with_value('central,ipmi')
+        should contain_ceilometer_config('compute/instance_discovery_method').with_ensure('absent')
+        should contain_ceilometer_config('compute/resource_update_interval').with_ensure('absent')
+        should contain_ceilometer_config('compute/resource_cache_expiry').with_ensure('absent')
+      }
+    end
+
+    context 'with central namespace disabled' do
+      before do
+        params.merge!(
+          :central_namespace => false,
+        )
+      end
+
+      it {
+        should contain_ceilometer_config('DEFAULT/polling_namespaces').with_value('compute,ipmi')
+        should contain_ceilometer_config('DEFAULT/tenant_name_discovery').with_ensure('absent')
+       }
+    end
+
     context 'with central and ipmi polling namespaces disabled' do
       before do
-        params.merge!( :central_namespace => false,
-                       :ipmi_namespace    => false )
+        params.merge!(
+          :central_namespace => false,
+          :ipmi_namespace    => false
+        )
       end
 
       it { should contain_ceilometer_config('DEFAULT/polling_namespaces').with_value('compute') }
     end
 
+    context 'with all namespaces disabled' do
+      before do
+        params.merge!(
+          :compute_namespace => false,
+          :central_namespace => false,
+          :ipmi_namespace    => false
+        )
+      end
+
+      it { should contain_ceilometer_config('DEFAULT/polling_namespaces').with_ensure('absent') }
+    end
+
     context 'with service disabled' do
       before do
         params.merge!( :enabled => false )
@@ -225,14 +288,6 @@ sources:
       it { should_not contain_file('polling') }
     end
 
-    context 'when setting coordination_url' do
-      before do
-        params.merge!( :coordination_url => 'redis://localhost:6379' )
-      end
-
-      it { should contain_ceilometer_config('coordination/backend_url').with_value('redis://localhost:6379') }
-    end
-
     context 'when batch_size is set' do
       before do
         params.merge!( :batch_size => 50 )
@@ -256,12 +311,14 @@ sources:
             {
               :agent_package_name => 'ceilometer-polling',
               :agent_service_name => 'ceilometer-polling',
-              :libvirt_group      => 'libvirt'
+              :libvirt_group      => 'libvirt',
+              :ceilometer_groups  => ['nova', 'libvirt'],
             }
         when 'RedHat'
             {
               :agent_package_name => 'openstack-ceilometer-polling',
-              :agent_service_name => 'openstack-ceilometer-polling'
+              :agent_service_name => 'openstack-ceilometer-polling',
+              :ceilometer_groups  => ['nova'],
             }
         end
       end
